@@ -1,17 +1,18 @@
 from __future__ import print_function
-import mahotas
+import mahotas as mh
 from pylab import gray, imshow, show
 import numpy as np
 
-luispedro = mahotas.imread('./data/luispedro.jpg')
+
+luispedro = mh.demos.load('luispedro')
 luispedro = luispedro.max(2)
-T = mahotas.otsu(luispedro)
+T = mh.otsu(luispedro)
 lpbin = (luispedro > T)
 eye = lpbin[112:180,100:190]
 gray()
 imshow(eye)
 show()
-imshow(~mahotas.morph.close(~eye))
+imshow(~mh.morph.close(~eye))
 show()
-imshow(~mahotas.morph.open(~eye))
+imshow(~mh.morph.open(~eye))
 show()
