@@ -22,7 +22,7 @@ __all__ = [
         'hitmiss',
         'locmax',
         'locmin',
-        'majority_filter'
+        'majority_filter',
         'open',
         'regmax',
         'regmin',
@@ -301,11 +301,10 @@ def cwatershed(surface, markers, Bc=None, return_lines=False):
         Regions image (i.e., W[i,j] == region for pixel (i,j))
     WL : Lines image (`if return_lines==True`)
     '''
-    _verify_is_integer_type(surface, 'cwatershed')
     _verify_is_integer_type(markers, 'cwatershed')
-    markers = markers.astype(np.int64)
     if surface.shape != markers.shape:
         raise ValueError('morph.cwatershed: Markers array should have the same shape as value array.')
+    markers = markers.astype(np.int64)
     Bc = get_structuring_elem(surface, Bc)
     return _morph.cwatershed(surface, markers, Bc, bool(return_lines))
 
@@ -622,7 +621,6 @@ def regmin(f, Bc=None, out=None, output=None):
     locmin : function
         Local minima
     '''
-    _verify_is_integer_type(f, 'regmin')
     Bc = get_structuring_elem(f, Bc)
     Bc = _remove_centre(Bc.copy())
     output = _get_output(f, out, 'regmin', np.bool_, output=output)
@@ -666,7 +664,6 @@ def regmax(f, Bc=None, out=None, output=None):
     locmax : function
         Local maxima. The local maxima are a superset of the regional maxima
     '''
-    _verify_is_integer_type(f, 'regmax')
     Bc = get_structuring_elem(f, Bc)
     Bc = _remove_centre(Bc.copy())
     output = _get_output(f, out, 'regmax', np.bool_, output=output)
